/*
 * AceDocumentChangeEventNative.java
 *
 * Copyright (C) 2022 by RStudio, PBC
 *
 * Unless you have received this program directly from RStudio pursuant
 * to the terms of a commercial license agreement with RStudio, then
 * this program is licensed to you under the terms of version 3 of the
 * GNU Affero General Public License. This program is distributed WITHOUT
 * ANY EXPRESS OR IMPLIED WARRANTY, INCLUDING THOSE OF NON-INFRINGEMENT,
 * MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. Please refer to the
 * AGPL (http://www.gnu.org/licenses/agpl-3.0.txt) for more details.
 *
 */
package org.rstudio.studio.client.workbench.views.source.editors.text.ace;

import jsinterop.annotations.JsType;

import com.google.gwt.core.client.JsArrayString;

import jsinterop.annotations.JsOverlay;
import jsinterop.annotations.JsPackage;

@JsType(isNative = true, namespace = JsPackage.GLOBAL, name = "Object")
public class AceDocumentChangeEventNative
{
   public String action;
   public Position start;
   public Position end;
   public JsArrayString lines;
   
   @JsOverlay
   public final Range getRange()
   {
      return Range.fromPoints(start, end);
   }
   
   @JsOverlay
   public final String getAction()
   {
      return action;
   }
}
